# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.jadmin.options import JumboModelAdmin
from .models import AddressScope


class AddressScopeAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (_('visualization admin'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {
            'fields': ('status', 'name', 'is_invoice_address', 'is_shipping_address')
        }),
    )
    list_display = (
        'get_status_display', 'name', 'is_invoice_address',
        'is_shipping_address', 'get_edit_icon', 'get_delete_icon'
    )
    list_display_links = ('name',)
    ordering = ('ordering', 'name')
admin.site.register(AddressScope, AddressScopeAdmin)


class AddressCoordinatesAdmin(admin.ModelAdmin):

    """Use this model admin to include necessary js to display google map
    for the stored coordinates.  If your inherited admin overwrites
    any attributes be careful to include these js in Media class and
    'google_map' as readonly field.

    """
    fieldsets = (
        (_('coordinates'), {
            'fields': ('lat', 'lng', 'google_map'),
        }),
    )
    list_display = ('lat', 'lng', 'get_edit_icon', 'get_delete_icon')
    readonly_fields = ('google_map',)

    class Media:
        js = (
            "https://maps.googleapis.com/maps/api/js?key={}".format(
                settings.ADDRESS_GOOGLE_GEOCODING_KEY),
            "address/js/address_coordinates.js",
        )
